summaryrefslogtreecommitdiffstats
path: root/kmail/snippetwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/snippetwidget.cpp')
-rw-r--r--kmail/snippetwidget.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmail/snippetwidget.cpp b/kmail/snippetwidget.cpp
index 4dba053e..920434aa 100644
--- a/kmail/snippetwidget.cpp
+++ b/kmail/snippetwidget.cpp
@@ -44,8 +44,8 @@
#include <cassert>
-SnippetWidget::SnippetWidget(KMEdit* editor, KActionCollection* actionCollection, TQWidget* tqparent)
- : KListView(tqparent, "snippet widget"), TQToolTip( viewport() ),
+SnippetWidget::SnippetWidget(KMEdit* editor, KActionCollection* actionCollection, TQWidget* parent)
+ : KListView(parent, "snippet widget"), TQToolTip( viewport() ),
mEditor( editor ), mActionCollection( actionCollection )
{
// init the TQPtrList
@@ -85,7 +85,7 @@ SnippetWidget::~SnippetWidget()
writeConfig();
delete _cfg;
/* We need to delete the child items before the tqparent items
otherwise KDevelop would crash on exiting */
SnippetItem * item;
while (_list.count() > 0) {
@@ -111,7 +111,7 @@ void SnippetWidget::slotAdd()
which the selected item is a child of*/
SnippetGroup * group = dynamic_cast<SnippetGroup*>(selectedItem());
if ( !group && selectedItem() )
- group = dynamic_cast<SnippetGroup*>(selectedItem()->tqparent());
+ group = dynamic_cast<SnippetGroup*>(selectedItem()->parent());
/* still no group, let's make a default one */
if (!group ) {
@@ -139,12 +139,12 @@ void SnippetWidget::slotAdd()
}
/*!
- \fn SnippetWidget::makeItem( SnippetItem* tqparent, const TQString& name, const TQString& text )
+ \fn SnippetWidget::makeItem( SnippetItem* parent, const TQString& name, const TQString& text )
Helper factory method.
*/
-SnippetItem* SnippetWidget::makeItem( SnippetItem* tqparent, const TQString& name, const TQString& text, const KShortcut& shortcut )
+SnippetItem* SnippetWidget::makeItem( SnippetItem* parent, const TQString& name, const TQString& text, const KShortcut& shortcut )
{
- SnippetItem * item = new SnippetItem(tqparent, name, text);
+ SnippetItem * item = new SnippetItem(parent, name, text);
const TQString actionName = i18n("Snippet %1").tqarg(name);
const TQString normalizedName = TQString(actionName).replace(" ", "_");
if ( !mActionCollection->action(normalizedName.utf8().data() ) ) {
@@ -255,10 +255,10 @@ void SnippetWidget::slotEdit( TQListViewItem* item )
pSnippet->setText( dlg.snippetText->text() );
pSnippet->getAction()->setShortcut( dlg.keyButton->shortcut());
- /* if the user changed the tqparent we need to move the snippet */
+ /* if the user changed the parent we need to move the snippet */
if ( SnippetItem::findGroupById(pSnippet->getParent(), _list)->getName() != dlg.cbGroup->currentText() ) {
SnippetGroup * newGroup = dynamic_cast<SnippetGroup*>(SnippetItem::findItemByName(dlg.cbGroup->currentText(), _list));
- pSnippet->tqparent()->takeItem(pSnippet);
+ pSnippet->parent()->takeItem(pSnippet);
newGroup->insertItem(pSnippet);
pSnippet->resetParent();
}
@@ -909,7 +909,7 @@ void SnippetWidget::slotDropped(TQDropEvent *e, TQListViewItem *)
SnippetGroup *group = dynamic_cast<SnippetGroup *>(item2);
if (!group)
- group = dynamic_cast<SnippetGroup *>(item2->tqparent());
+ group = dynamic_cast<SnippetGroup *>(item2->parent());
TQCString dropped;
TQByteArray data = e->tqencodedData("text/plain");
@@ -85,7 +85,7 @@ SnippetWidget::~SnippetWidget()
writeConfig();
delete _cfg;
- /* We need to delete the child items before the tqparent items
+ /* We need to delete the child items before the parent items
otherwise KDevelop would crash on exiting */
SnippetItem * item;